;; Generated package description from mct.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "mct" "1.1.0" "Minibuffer Confines Transcended" '((emacs "29.1")) :commit "306cb704196c643b552aceb5893693641ca747d9" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/mct")
